@@ -12,3 +12,6 @@ DATABASES = {
         'db': 'example',
     }
 }
+
+# Only used for pylytics.plugins.nameko
+NAMEKO_AMQP_URI = 'amqp://pylytics:pylytics@localhost:5672/pylytics'
